@@ -133,7 +133,7 @@ int main( int argc, char *argv[] )
   try {
     dac.openStream( &parameters, NULL, format, (unsigned int)Stk::sampleRate(), &bufferFrames, &tick, (void *)&data );
   }
-  catch ( RtError &error ) {
+  catch ( RtAudioError &error ) {
     error.printMessage();
     goto cleanup;
   }
@@ -152,7 +152,7 @@ int main( int argc, char *argv[] )
   try {
     dac.startStream();
   }
-  catch ( RtError &error ) {
+  catch ( RtAudioError &error ) {
     error.printMessage();
     goto cleanup;
   }
@@ -165,7 +165,7 @@ int main( int argc, char *argv[] )
   try {
     dac.closeStream();
   }
-  catch ( RtError &error ) {
+  catch ( RtAudioError &error ) {
     error.printMessage();
   }
 
