@@ -17,7 +17,7 @@
     type, the data type will automatically be modified.  Compressed
     data types are not supported.
 
-    by Perry R. Cook and Gary P. Scavone, 1995-2012.
+    by Perry R. Cook and Gary P. Scavone, 1995--2014.
 */
 /***************************************************/
 
@@ -247,9 +247,7 @@ bool FileWrite :: setWavFile( std::string fileName )
   hdr.bytesPerSecond = (SINT32) (hdr.sampleRate * hdr.bytesPerSample);
 
   unsigned int bytesToWrite = 36;
-  bool useExtensible = false;
   if ( channels_ > 2 || hdr.bitsPerSample > 16 ) { // use extensible format
-    useExtensible = true;
     bytesToWrite = 72;
     hdr.chunkSize += 24;
     hdr.formatCode = 0xFFFE;
@@ -311,7 +309,7 @@ void FileWrite :: closeWavFile( void )
     dataLocation = 76;
   }
 
-  SINT32 bytes = frameCounter_ * channels_ * bytesPerSample;
+  SINT32 bytes = (SINT32) (frameCounter_ * channels_ * bytesPerSample);
   if ( bytes % 2 ) { // pad extra byte if odd
     signed char sample = 0;
     fwrite( &sample, 1, 1, fd_ );
@@ -322,7 +320,7 @@ void FileWrite :: closeWavFile( void )
   fseek( fd_, dataLocation, SEEK_SET ); // jump to data length
   fwrite( &bytes, 4, 1, fd_ );
 
-  bytes = frameCounter_ * channels_ * bytesPerSample + 44;
+  bytes = (SINT32) (frameCounter_ * channels_ * bytesPerSample + 44);
   if ( useExtensible ) bytes += 36;
 #ifndef __LITTLE_ENDIAN__
   swap32((unsigned char *)&bytes);
@@ -331,7 +329,7 @@ void FileWrite :: closeWavFile( void )
   fwrite( &bytes, 4, 1, fd_ );
 
   if ( useExtensible ) { // fill in the "fact" chunk frames value
-    bytes = frameCounter_;
+    bytes = (SINT32) frameCounter_;
 #ifndef __LITTLE_ENDIAN__
     swap32((unsigned char *)&bytes);
 #endif
@@ -401,7 +399,7 @@ void FileWrite :: closeSndFile( void )
   else if ( dataType_ == STK_FLOAT64 )
     bytesPerSample = 8;
 
-  SINT32 bytes = frameCounter_ * bytesPerSample * channels_;
+  SINT32 bytes = (SINT32) (frameCounter_ * bytesPerSample * channels_);
 #ifdef __LITTLE_ENDIAN__
   swap32 ((unsigned char *)&bytes);
 #endif
@@ -459,7 +457,7 @@ bool FileWrite :: setAifFile( std::string fileName )
 #ifdef __LITTLE_ENDIAN__
   swap16((unsigned char *)&i);
 #endif
-  *(SINT16 *)(hdr.srate) = (SINT16) i;
+  memcpy( hdr.srate, &i, sizeof(SINT16) );
 
   for ( i=32; i; i-- ) {
     if ( rate & 0x80000000 ) break;
@@ -469,7 +467,7 @@ bool FileWrite :: setAifFile( std::string fileName )
 #ifdef __LITTLE_ENDIAN__
   swap32((unsigned char *)&rate);
 #endif
-  *(unsigned long *)(hdr.srate+2) = (unsigned long) rate;
+  memcpy( hdr.srate + 2, &rate, sizeof(rate) );
 
   byteswap_ = false;  
 #ifdef __LITTLE_ENDIAN__
@@ -572,7 +570,7 @@ bool FileWrite :: setMatFile( std::string fileName )
 
   struct MatHeader hdr;
   strcpy( hdr.heading,"MATLAB 5.0 MAT-file, Generated using the Synthesis ToolKit in C++ (STK). By Perry R. Cook and Gary P. Scavone." );
-  for ( int i=strlen(hdr.heading); i<124; i++ ) hdr.heading[i] = ' ';
+  for ( size_t i =strlen(hdr.heading); i<124; i++ ) hdr.heading[i] = ' ';
 
   // Header Flag Fields
   hdr.hff[0] = (SINT16) 0x0100;   // Version field
@@ -690,7 +688,11 @@ void FileWrite :: closeMatFile( void )
 
   SINT32 headsize, temp;
   fseek(fd_, 196, SEEK_SET);  // jump to header size
-  fread(&headsize, 4, 1, fd_);
+  if (fread(&headsize, 4, 1, fd_) < 4) {
+      oStream_ << "FileWrite: could not read MAT-file header size.";
+      goto close_file;
+  }
+
   temp = headsize;
   headsize += (SINT32) (frameCounter_ * 8 * channels_);
   fseek(fd_, 196, SEEK_SET);
@@ -698,9 +700,10 @@ void FileWrite :: closeMatFile( void )
   fwrite(&headsize, 4, 1, fd_);
 
   fseek(fd_, temp+196, SEEK_SET); // jumpt to data size (in bytes)
-  temp = frameCounter_ * 8 * channels_;
+  temp = (SINT32) (frameCounter_ * 8 * channels_);
   fwrite(&temp, 4, 1, fd_);
 
+close_file:
   fclose(fd_);
 }
 
