@@ -14,7 +14,7 @@
     that takes a reference to an StkFrames object for multi-channel
     and/or multi-frame data.
 
-    by Perry R. Cook and Gary P. Scavone, 1995-2012.
+    by Perry R. Cook and Gary P. Scavone, 1995--2014.
 */
 /***************************************************/
 
@@ -107,7 +107,7 @@ RtWvOut :: RtWvOut( unsigned int nChannels, StkFloat sampleRate, int device, int
   try {
     dac_.openStream( &parameters, NULL, format, (unsigned int)Stk::sampleRate(), &size, &write, (void *)this );
   }
-  catch ( RtError &error ) {
+  catch ( RtAudioError &error ) {
     handleError( error.what(), StkError::AUDIO_SYSTEM );
   }
 
