@@ -12,7 +12,7 @@
        - Blowing Frequency Modulation = 2
        - Volume = 128
 
-    by Perry R. Cook  1995-2012.
+    by Perry R. Cook  1995--2014.
 */
 /***************************************************/
 
@@ -27,11 +27,11 @@ const int PEA_RADIUS = 30;
 const int BUMP_RADIUS = 5;
 
 const StkFloat NORM_CAN_LOSS = 0.97;
-const StkFloat SLOW_CAN_LOSS = 0.90;
+//const StkFloat SLOW_CAN_LOSS = 0.90;
 const StkFloat GRAVITY = 20.0;
 
 const StkFloat NORM_TICK_SIZE = 0.004;
-const StkFloat SLOW_TICK_SIZE = 0.0001;
+//const StkFloat SLOW_TICK_SIZE = 0.0001;
 
 const StkFloat ENV_RATE = 0.001;
 
